Repositories
============
The following is an incomplete listing of the repositories for Bio2BEL. This list is always increasing, and can
be searched directly through the Bio2BEL `GitHub Organization <https://github.com/bio2bel>`_.

+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| Source                 | Version             | Documentation                     | Travis               | DOI                   |
+========================+=====================+===================================+======================+=======================+
| ADEPTUS                | |adeptus_pypi|      | |adeptus_docs|                    | |adeptus_build|      | |adeptus_zenodo|      |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| ChEBI                  | |chebi_pypi|        | |chebi_docs|                      | |chebi_build|        | |chebi_zenodo|        |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| CREEDS                 |                     |                                   |                      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| Complex Portal         |                     |                                   |                      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| CTD                    | |ctd_pypi|          | |ctd_docs|                        | |ctd_build|          |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| DDR                    |                     |                                   |                      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| DrugBank               | |drugbank_pypi|     | |drugbank_docs|                   | |drugbank_build|     | |drugbank_zenodo|     |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| Entrez                 | |entrez_pypi|       | |entrez_docs|                     | |entrez_build|       | |entrez_zenodo|       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| ExCAPE-DB              | |excape_pypi|       | |excape_docs|                     | |excape_build|       |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| ExPASy                 | |expasy_pypi|       | |expasy_docs|                     | |expasy_build|       | |expasy_zenodo|       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| FamPlex                | |famplex_pypi|      | |famplex_docs|                    | |famplex_build|      | |famplex_zenodo|      |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| FlyBase                | |flybase_pypi|      | |flybase_docs|                    | |flybase_build|      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| GO                     | |go_pypi|           | |go_docs|                         | |go_build|           | |go_zenodo|           |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| GWAS Catalog           |                     |                                   |                      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| HGNC                   | |hgnc_pypi|         | |hgnc_docs|                       | |hgnc_build|         | |hgnc_zenodo|         |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| HIPPIE                 | |hippie_pypi|       | |hippie_docs|                     | |hippie_build|       | |hippie_zenodo|       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| HMDB                   | |hmdb_pypi|         | |hmdb_docs|                       | |hmdb_build|         |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| HSDN                   | |hsdn_pypi|         | |hsdn_docs|                       | |hsdn_build|         | |hsdn_zenodo|         |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| InterPro               | |interpro_pypi|     | |interpro_docs|                   | |interpro_build|     | |interpro_zenodo|     |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| KEGG                   | |kegg_pypi|         | |kegg_docs|                       | |kegg_build|         | |kegg_zenodo|         |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| MeSH                   | |mesh_pypi|         | |mesh_docs|                       | |mesh_build|         | |mesh_zenodo|         |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| MGI                    | |mgi_pypi|          | |mgi_docs|                        | |mgi_build|          |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| miRBase                | |mirbase_pypi|      | |mirbase_docs|                    | |mirbase_build|      | |mirbase_zenodo|      |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| miRTarBase             | |mirtarbase_pypi|   | |mirtarbase_docs|                 | |mirtarbase_build|   | |mirtarbase_zenodo|   |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| MSigDB                 | |msig_pypi|         | |msig_docs|                       | |msig_build|         | |msig_zenodo|         |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| PFAM                   |                     |                                   |                      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| PhosphoSitePlus        | |phosphosite_pypi|  | |phosphosite_docs|                | |phosphosite_build|  |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| PID                    |                     | :mod:`bio2bel.sources.pid`        |                      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| PubChem                | |pubchem_pypi|      | |pubchem_docs|                    | |pubchem_build|      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| Reactome               | |reactome_pypi|     | |reactome_docs|                   | |reactome_build|     | |reactome_zenodo|     |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| RGD                    | |rgd_pypi|          | |rgd_docs|                        | |rgd_build|          |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| SIDER                  | |sider_pypi|        | |sider_docs|                      | |sider_build|        |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| TFRegulons             |                     | :mod:`bio2bel.sources.tfregulons` |                      |                       |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| UniProt                | |uniprot_pypi|      | |uniprot_docs|                    | |uniprot_build|      | |uniprot_zenodo|      |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+
| WikiPathways           | |wikipathways_pypi| | |wikipathways_docs|               | |wikipathways_build| | |wikipathways_zenodo| |
+------------------------+---------------------+-----------------------------------+----------------------+-----------------------+

.. |excape_pypi| image:: https://img.shields.io/pypi/v/bio2bel_excape.svg
    :alt: Current ExCAPE-DB version on PyPI
.. |excape_docs| image:: https://readthedocs.org/projects/bio2bel-excape-db/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/excape/en/latest/?badge=latest
    :alt: ExCAPE-DB Documentation Status
.. |excape_build| image:: https://travis-ci.com/bio2bel/excape.svg?branch=master
    :target: https://travis-ci.com/bio2bel/excape
    :alt: ExCAPE-DB Build Status

.. |flybase_pypi| image:: https://img.shields.io/pypi/v/bio2bel_flybase.svg
    :alt: Current FlyBase version on PyPI
.. |flybase_build| image:: https://travis-ci.org/bio2bel/flybase.svg?branch=master
    :target: https://travis-ci.org/bio2bel/flybase
    :alt: FlyBase Build Status
.. |flybase_docs| image:: https://readthedocs.org/projects/bio2bel-flybase/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/flybase/en/latest/?badge=latest
    :alt: Flybase Documentation Status

.. |hippie_pypi| image:: https://img.shields.io/pypi/v/bio2bel_hippie.svg
    :alt: Current HIPPIE version on PyPI
.. |hippie_docs| image:: https://readthedocs.org/projects/bio2bel-hippie/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/hippie/en/latest/?badge=latest
    :alt: HIPPIE Documentation Status
.. |hippie_build| image:: https://travis-ci.com/bio2bel/hippie.svg?branch=master
    :target: https://travis-ci.com/bio2bel/hippie
    :alt: HIPPIE Build Status
.. |hippie_zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1435930.svg
    :target: https://doi.org/10.5281/zenodo.1435930
    :alt: Bio2BEL HIPPIE Zenodo DOI

.. |mgi_pypi| image:: https://img.shields.io/pypi/v/bio2bel_mgi.svg
    :alt: Current MGI version on PyPI
.. |mgi_build| image:: https://travis-ci.org/bio2bel/mgi.svg?branch=master
    :target: https://travis-ci.org/bio2bel/mgi
    :alt: MGI Build Status
.. |mgi_docs| image:: https://readthedocs.org/projects/bio2bel-mgi/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/mgi/en/latest/?badge=latest
    :alt: MGI Documentation Status

.. |rgd_pypi| image:: https://img.shields.io/pypi/v/bio2bel_rgd.svg
    :alt: Current RGD version on PyPI
.. |rgd_build| image:: https://travis-ci.com/bio2bel/rgd.svg?branch=master
    :target: https://travis-ci.com/bio2bel/rgd
    :alt: RGD Build Status
.. |rgd_docs| image:: https://readthedocs.org/projects/bio2bel-rgd/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/rgd/en/latest/?badge=latest
    :alt: RGD Documentation Status

.. |mirbase_pypi| image:: https://img.shields.io/pypi/v/bio2bel_mirbase.svg
    :alt: Current miRBase version on PyPI
.. |mirbase_docs| image:: https://readthedocs.org/projects/bio2bel-mirbase/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/mirbase/en/latest/?badge=latest
    :alt: miRBase Documentation Status
.. |mirbase_build| image:: https://travis-ci.com/bio2bel/mirbase.svg?branch=master
    :target: https://travis-ci.com/bio2bel/mirbase
    :alt: miRBase Build Status
.. |mirbase_zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1442206.svg
    :target: https://doi.org/10.5281/zenodo.1442206
    :alt: Bio2BEL miRBase Zenodo DOI


.. |mirtarbase_pypi| image:: https://img.shields.io/pypi/v/bio2bel_mirtarbase.svg
    :alt: Current miRTarBase version on PyPI

.. |mirtarbase_docs| image:: https://readthedocs.org/projects/mirtarbase/badge/?version=latest
    :target: http://mirtarbase.readthedocs.io
    :alt: miRTarBase Documentation Status

.. |mirtarbase_build| image:: https://travis-ci.org/bio2bel/mirtarbase.svg?branch=master
    :target: https://travis-ci.org/bio2bel/mirtarbase
    :alt: miRTarBase Build Status

.. |mirtarbase_zenodo| image:: https://zenodo.org/badge/95350968.svg
    :target: https://zenodo.org/badge/latestdoi/95350968
    :alt: Bio2BEL miRTarBase Zenodo DOI


.. |expasy_pypi| image:: https://img.shields.io/pypi/v/bio2bel_expasy.svg
    :alt: Current ExPASy version on PyPI

.. |expasy_build| image:: https://travis-ci.org/bio2bel/expasy.svg?branch=master
    :target: https://travis-ci.org/bio2bel/expasy
    :alt: ExPASy Build Status

.. |expasy_docs| image:: http://readthedocs.org/projects/bio2bel-expasy/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/expasy/en/latest/?badge=latest
    :alt: ExPASy Documentation Status

.. |expasy_zenodo| image:: https://zenodo.org/badge/100023822.svg
    :target: https://zenodo.org/badge/latestdoi/100023822
    :alt: Bio2BEL ExPASy Zenodo DOI



.. |interpro_pypi| image:: https://img.shields.io/pypi/v/bio2bel_interpro.svg
    :alt: Current InterPro version on PyPI

.. |interpro_build| image:: https://travis-ci.org/bio2bel/interpro.svg?branch=master
    :target: https://travis-ci.org/bio2bel/interpro
    :alt: InterPro Build Status

.. |interpro_docs| image:: http://readthedocs.org/projects/bio2bel-interpro/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/interpro/en/latest/?badge=latest
    :alt: InterPro Documentation Status

.. |interpro_zenodo| image:: https://zenodo.org/badge/98345182.svg
    :target: https://zenodo.org/badge/latestdoi/98345182
    :alt: Bio2BEL InterPro Zenodo DOI


.. |ctd_pypi| image:: https://img.shields.io/pypi/v/bio2bel_ctd.svg
    :alt: Current CTD version on PyPI

.. |ctd_build| image:: https://travis-ci.org/bio2bel/ctd.svg?branch=master
    :target: https://travis-ci.org/bio2bel/ctd
    :alt: CTD Build Status

.. |ctd_docs| image:: https://readthedocs.org/projects/bio2bel-ctd/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/ctd/en/latest/?badge=latest
    :alt: CTD Documentation Status



.. |phosphosite_pypi| image:: https://img.shields.io/pypi/v/bio2bel_phosphosite.svg
    :alt: Current PhosphoSitePlus version on PyPI

.. |phosphosite_build| image:: https://travis-ci.org/bio2bel/phosphosite.svg?branch=master
    :target: https://travis-ci.org/bio2bel/phosphosite
    :alt: PhosphoSitePlus Build Status

.. |phosphosite_docs| image:: https://readthedocs.org/projects/bio2bel-phosphositeplus/badge/?version=latest
    :target: https://bio2bel.readthedocs.io/projects/phosphosite/en/latest/?badge=latest
    :alt: PhosphoSitePlus Documentation Status



.. |sider_pypi| image:: https://img.shields.io/pypi/v/bio2bel_sider.svg
    :alt: Current SIDER version on PyPI

.. |sider_build| image:: https://travis-ci.com/bio2bel/sider.svg?branch=master
    :target: https://travis-ci.com/bio2bel/sider
    :alt: SIDER Build Status

.. |sider_docs| image:: http://readthedocs.org/projects/bio2bel-sider/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/sider/en/latest/?badge=latest
    :alt: SIDER Documentation Status



.. |kegg_pypi| image:: https://img.shields.io/pypi/v/bio2bel_KEGG.svg
    :alt: Current KEGG version on PyPI

.. |kegg_build| image:: https://travis-ci.org/bio2bel/kegg.svg?branch=master
    :target: https://travis-ci.org/bio2bel/kegg
    :alt: KEGG Build Status

.. |kegg_docs| image:: http://readthedocs.org/projects/bio2bel-interpro/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/kegg/en/latest/?badge=latest
    :alt: KEGG Documentation Status

.. |kegg_zenodo| image:: https://zenodo.org/badge/105248163.svg
    :target: https://zenodo.org/badge/latestdoi/105248163
    :alt: KEGG Zenodo DOI



.. |reactome_pypi| image:: https://img.shields.io/pypi/v/bio2bel_reactome.svg
    :alt: Current Reactome version on PyPI

.. |reactome_build| image:: https://travis-ci.org/bio2bel/reactome.svg?branch=master
    :target: https://travis-ci.org/bio2bel/reactome
    :alt: Reactome Build Status

.. |reactome_docs| image:: http://readthedocs.org/projects/bio2bel-interpro/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/reactome/en/latest/?badge=latest
    :alt: Reactome Documentation Status

.. |reactome_zenodo| image:: https://zenodo.org/badge/103138323.svg
    :target: https://zenodo.org/badge/latestdoi/103138323
    :alt: Reactome Zenodo DOI



.. |wikipathways_pypi| image:: https://img.shields.io/pypi/v/bio2bel_wikipathways.svg
    :alt: Current WikiPathways version on PyPI

.. |wikipathways_build| image:: https://travis-ci.org/bio2bel/wikipathways.svg?branch=master
    :target: https://travis-ci.org/bio2bel/wikipathways
    :alt: WikiPathways Build Status

.. |wikipathways_docs| image:: http://readthedocs.org/projects/bio2bel-interpro/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/wikipathways/en/latest/?badge=latest
    :alt: WikiPathways Documentation Status

.. |wikipathways_zenodo| image:: https://zenodo.org/badge/118924155.svg
    :target: https://zenodo.org/badge/latestdoi/118924155
    :alt: WikiPathways Zenodo DOI



.. |msig_build| image:: https://travis-ci.org/bio2bel/msig.svg?branch=master
    :target: https://travis-ci.org/bio2bel/msig
    :alt: MSigDB Build Status

.. |msig_docs| image:: http://readthedocs.org/projects/bio2bel-msig/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/msig/en/latest/?badge=latest
    :alt: Documentation Status

.. |msig_pypi| image:: https://img.shields.io/pypi/v/bio2bel_msig.svg
    :alt: Current version of MSigDB on PyPI

.. |msig_zenodo| image:: https://zenodo.org/badge/123948554.svg
    :target: https://zenodo.org/badge/latestdoi/123948554
    :alt: Bio2BEL MSigDB Zenodo DOI


.. |mesh_build| image:: https://travis-ci.com/bio2bel/mesh.svg?branch=master
    :target: https://travis-ci.com/bio2bel/mesh
    :alt: Build Status

.. |mesh_docs| image:: https://readthedocs.org/projects/mesh/badge/?version=latest
    :target: http://mesh.readthedocs.io
    :alt: Documentation Status

.. |mesh_pypi| image:: https://img.shields.io/pypi/v/bio2bel_mesh.svg
    :alt: Current version on PyPI

.. |mesh_zenodo| image:: https://zenodo.org/badge/107369801.svg
    :target: https://zenodo.org/badge/latestdoi/107369801
    :alt: Bio2BEL MeSH Zenodo DOI



.. |chebi_build| image:: https://travis-ci.org/bio2bel/chebi.svg?branch=master
    :target: https://travis-ci.org/bio2bel/chebi
    :alt: Build Status

.. |chebi_docs| image:: http://readthedocs.org/projects/bio2bel-chebi/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/chebi/en/latest/?badge=latest
    :alt: Documentation Status

.. |chebi_pypi| image:: https://img.shields.io/pypi/v/bio2bel_chebi.svg
    :alt: Current version on PyPI

.. |chebi_zenodo| image:: https://zenodo.org/badge/97003706.svg
    :target: https://zenodo.org/badge/latestdoi/97003706
    :alt: Bio2BEL ChEBI Zenodo DOI



.. |uniprot_build| image:: https://travis-ci.com/bio2bel/uniprot.svg?branch=master
    :target: https://travis-ci.com/bio2bel/uniprot
    :alt: Build Status

.. |uniprot_docs| image:: http://readthedocs.org/projects/bio2bel-uniprot/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/uniprot/en/latest/?badge=latest
    :alt: Documentation Status

.. |uniprot_pypi| image:: https://img.shields.io/pypi/v/bio2bel_uniprot.svg
    :alt: Current version on PyPI

.. |uniprot_zenodo| image:: https://zenodo.org/badge/99588558.svg
   :target: https://zenodo.org/badge/latestdoi/99588558
   :alt: Bio2BEL UniProt Zenodo DOI

.. |drugbank_build| image:: https://travis-ci.org/bio2bel/drugbank.svg?branch=master
    :target: https://travis-ci.org/bio2bel/drugbank
    :alt: Build Status

.. |drugbank_docs| image:: http://readthedocs.org/projects/bio2bel-drugbank/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/drugbank/en/latest/?badge=latest
    :alt: Documentation Status

.. |drugbank_pypi| image:: https://img.shields.io/pypi/v/bio2bel_drugbank.svg
    :alt: Current version on PyPI

.. |drugbank_zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1243727.svg
    :target: https://doi.org/10.5281/zenodo.1243727
    :alt: Zenodo DOI



.. |pubchem_build| image:: https://travis-ci.org/bio2bel/pubchem.svg?branch=master
    :target: https://travis-ci.org/bio2bel/pubchem
    :alt: Build Status

.. |pubchem_docs| image:: http://readthedocs.org/projects/bio2bel-pubchem/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/pubchem/en/latest/?badge=latest
    :alt: Documentation Status

.. |pubchem_pypi| image:: https://img.shields.io/pypi/v/bio2bel_pubchem.svg
    :alt: Current version on PyPI



.. |hmdb_build| image:: https://travis-ci.org/bio2bel/hmdb.svg?branch=master
    :target: https://travis-ci.org/bio2bel/hmdb
    :alt: Build Status

.. |hmdb_docs| image:: http://readthedocs.org/projects/bio2bel-hmdb/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/hmdb/en/latest/?badge=latest
    :alt: Documentation Status

.. |hmdb_pypi| image:: https://img.shields.io/pypi/v/bio2bel_hmdb.svg
    :alt: Current version on PyPI



.. |hgnc_build| image:: https://travis-ci.org/bio2bel/hgnc.svg?branch=master
    :target: https://travis-ci.org/bio2bel/hgnc
    :alt: Build Status

.. |hgnc_docs| image:: http://readthedocs.org/projects/bio2bel-hgnc/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/hgnc/en/latest/?badge=latest
    :alt: Documentation Status

.. |hgnc_pypi| image:: https://img.shields.io/pypi/v/bio2bel_hgnc.svg
    :alt: Current version on PyPI

.. |hgnc_zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1162644.svg
    :target: https://doi.org/10.5281/zenodo.1162644
    :alt: Bio2BEL HGNC Zenodo DOI


.. |entrez_build| image:: https://travis-ci.org/bio2bel/entrez.svg?branch=master
    :target: https://travis-ci.org/bio2bel/entrez
    :alt: Build Status

.. |entrez_docs| image:: http://readthedocs.org/projects/bio2bel-entrez/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/entrez/en/latest/?badge=latest
    :alt: Documentation Status

.. |entrez_pypi| image:: https://img.shields.io/pypi/v/bio2bel_entrez.svg
    :alt: Current version on PyPI

.. |entrez_zenodo| image:: https://zenodo.org/badge/100375120.svg
   :target: https://zenodo.org/badge/latestdoi/100375120
   :alt: Bio2BEL Entrez Zenodo DOI



.. |go_build| image:: https://travis-ci.org/bio2bel/go.svg?branch=master
    :target: https://travis-ci.org/bio2bel/go
    :alt: Build Status
.. |go_docs| image:: http://readthedocs.org/projects/bio2bel-go/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/go/en/latest/?badge=latest
    :alt: Documentation Status
.. |go_pypi| image:: https://img.shields.io/pypi/v/bio2bel_go.svg
    :alt: Current version on PyPI
.. |go_zenodo| image:: https://zenodo.org/badge/99944678.svg
   :target: https://zenodo.org/badge/latestdoi/99944678
   :alt: Bio2BEL GO Zenodo DOI

.. |famplex_pypi| image:: https://img.shields.io/pypi/v/bio2bel_famplex.svg
    :alt: Current version on PyPI
.. |famplex_docs| image:: https://readthedocs.org/projects/bio2bel-famplex/badge/?version=latest
    :target: https://bio2bel-famplex.readthedocs.io/en/latest/?badge=latest
    :alt: FamPlex Documentation Status
.. |famplex_build| image:: https://travis-ci.com/bio2bel/famplex.svg?branch=master
    :target: https://travis-ci.com/bio2bel/famplex
    :alt: Bio2BEL FamPlex Build Status
.. |famplex_zenodo| image:: https://zenodo.org/badge/135121081.svg
    :target: https://zenodo.org/badge/latestdoi/135121081
    :alt: Bio2BEL FamPlex Zenodo DOI

.. |hsdn_build| image:: https://travis-ci.com/bio2bel/hsdn.svg?branch=master
    :target: https://travis-ci.com/bio2bel/hsdn
    :alt: Build Status
.. |hsdn_docs| image:: http://readthedocs.org/projects/bio2bel-hsdn/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/hsdn/en/latest/?badge=latest
    :alt: Documentation Status
.. |hsdn_pypi| image:: https://img.shields.io/pypi/v/bio2bel_hsdn.svg
    :alt: Current version on PyPI
.. |hsdn_zenodo| image:: https://zenodo.org/badge/158366852.svg
    :target: https://zenodo.org/badge/latestdoi/158366852
    :alt: HSDN FamPlex Zenodo DOI

.. |adeptus_build| image:: https://travis-ci.com/bio2bel/adeptus.svg?branch=master
    :target: https://travis-ci.com/bio2bel/adeptus
    :alt: Build Status
.. |adeptus_docs| image:: http://readthedocs.org/projects/bio2bel-adeptus/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/adeptus/en/latest/?badge=latest
    :alt: Documentation Status
.. |adeptus_pypi| image:: https://img.shields.io/pypi/v/bio2bel_adeptus.svg
    :alt: Current version on PyPI
.. |adeptus_zenodo| image:: https://zenodo.org/badge/158358036.svg
    :target: https://zenodo.org/badge/latestdoi/158358036
    :alt: ADEPTUS FamPlex Zenodo DOI
